"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findRelSchemaAndField = exports.toError = exports.toArray = exports.isDevelopment = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.activeField = activeField;
exports.findRelUiSchema = findRelUiSchema;

var _utils = require("json-rules-engine-simplified/lib/utils");

var _utils2 = require("react-jsonschema-form/lib/utils");

var isDevelopment = exports.isDevelopment = function isDevelopment() {
  return process.env.NODE_ENV !== "production";
};

function fieldWithPrefix(field, prefix) {
  return prefix ? prefix + "." + field : field;
}

function activeField() {
  var formData = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var changedFormData = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var prefix = arguments[2];

  var existingFields = Object.keys(formData);
  var diffField = existingFields.find(function (field) {
    return !(0, _utils2.deepEquals)(formData[field], changedFormData[field]);
  });
  if (diffField) {
    var diffFieldVal = formData[diffField];
    if (Array.isArray(diffFieldVal)) {
      return undefined;
    } else if ((typeof diffFieldVal === "undefined" ? "undefined" : _typeof(diffFieldVal)) === "object") {
      return activeField(diffFieldVal, changedFormData[diffField], fieldWithPrefix(diffField, prefix));
    } else {
      return fieldWithPrefix(diffField, prefix);
    }
  }

  var newField = Object.keys(changedFormData).find(function (field) {
    return !existingFields.includes(field);
  });
  if (newField) {
    var newFieldVal = changedFormData[newField];
    if (Array.isArray(newFieldVal)) {
      return undefined;
    } else if ((typeof newFieldVal === "undefined" ? "undefined" : _typeof(newFieldVal)) === "object") {
      return activeField({}, newFieldVal, fieldWithPrefix(newField, prefix));
    } else {
      return fieldWithPrefix(newField, prefix);
    }
  }
}

var toArray = exports.toArray = function toArray(field) {
  if (Array.isArray(field)) {
    return field;
  } else {
    return [field];
  }
};

var toError = exports.toError = function toError(message) {
  if (isDevelopment()) {
    throw new ReferenceError(message);
  } else {
    console.error(message);
  }
};

/**
 * Find relevant schema for the field
 * @returns { field: "string", schema: "object" } relevant field and schema
 */
var findRelSchemaAndField = exports.findRelSchemaAndField = function findRelSchemaAndField(field, schema) {
  var separator = field.indexOf(".");
  if (separator === -1) {
    return { field: field, schema: schema };
  }

  var parentField = field.substr(0, separator);
  var refSchema = (0, _utils.extractRefSchema)(parentField, schema);
  if (refSchema) {
    return findRelSchemaAndField(field.substr(separator + 1), refSchema);
  }

  toError("Failed to retrieve " + refSchema + " from schema");
  return { field: field, schema: schema };
};

function findRelUiSchema(field, uiSchema) {
  var separator = field.indexOf(".");
  if (separator === -1) {
    return uiSchema;
  }

  var parentField = field.substr(0, separator);
  var refUiSchema = uiSchema[parentField];
  if (!refUiSchema) {
    return uiSchema;
  } else {
    return findRelUiSchema(field.substr(separator + 1), refUiSchema);
  }
}